==> zio-aws-computeoptimizer_3-5.17.125.1-sources.jar: zio/aws/computeoptimizer/model/GetRecommendationSummariesResponse.scala <==
package zio.aws.computeoptimizer.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.computeoptimizer.model.primitives.NextToken
import scala.jdk.CollectionConverters.*
final case class GetRecommendationSummariesResponse(
    nextToken: Option[NextToken] = None,
    recommendationSummaries: Option[
      Iterable[zio.aws.computeoptimizer.model.RecommendationSummary]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.computeoptimizer.model.GetRecommendationSummariesResponse = {
    import GetRecommendationSummariesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.computeoptimizer.model.GetRecommendationSummariesResponse
      .builder()
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        recommendationSummaries.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.recommendationSummaries)
      .build()
  }
  def asReadOnly
      : zio.aws.computeoptimizer.model.GetRecommendationSummariesResponse.ReadOnly =
    zio.aws.computeoptimizer.model.GetRecommendationSummariesResponse
      .wrap(buildAwsValue())
}
object GetRecommendationSummariesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.computeoptimizer.model.GetRecommendationSummariesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.computeoptimizer.model.GetRecommendationSummariesResponse =
      zio.aws.computeoptimizer.model.GetRecommendationSummariesResponse(
        nextToken.map(value => value),
        recommendationSummaries.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def nextToken: Option[NextToken]
    def recommendationSummaries: Option[
      List[zio.aws.computeoptimizer.model.RecommendationSummary.ReadOnly]
    ]
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getRecommendationSummaries: ZIO[Any, AwsError, List[
      zio.aws.computeoptimizer.model.RecommendationSummary.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "recommendationSummaries",
      recommendationSummaries
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.computeoptimizer.model.GetRecommendationSummariesResponse
  ) extends zio.aws.computeoptimizer.model.GetRecommendationSummariesResponse.ReadOnly {
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.computeoptimizer.model.primitives.NextToken(value))
    override val recommendationSummaries: Option[
      List[zio.aws.computeoptimizer.model.RecommendationSummary.ReadOnly]
    ] = scala
      .Option(impl.recommendationSummaries())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.computeoptimizer.model.RecommendationSummary.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.computeoptimizer.model.GetRecommendationSummariesResponse
  ): zio.aws.computeoptimizer.model.GetRecommendationSummariesResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-computeoptimizer_3-5.19.7.6-sources.jar: zio/aws/computeoptimizer/model/GetRecommendationSummariesResponse.scala <==
package zio.aws.computeoptimizer.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.computeoptimizer.model.primitives.NextToken
import scala.jdk.CollectionConverters.*
final case class GetRecommendationSummariesResponse(
    nextToken: Optional[NextToken] = Optional.Absent,
    recommendationSummaries: Optional[
      Iterable[zio.aws.computeoptimizer.model.RecommendationSummary]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.computeoptimizer.model.GetRecommendationSummariesResponse = {
    import GetRecommendationSummariesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.computeoptimizer.model.GetRecommendationSummariesResponse
      .builder()
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        recommendationSummaries.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.recommendationSummaries)
      .build()
  }
  def asReadOnly
      : zio.aws.computeoptimizer.model.GetRecommendationSummariesResponse.ReadOnly =
    zio.aws.computeoptimizer.model.GetRecommendationSummariesResponse
      .wrap(buildAwsValue())
}
object GetRecommendationSummariesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.computeoptimizer.model.GetRecommendationSummariesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.computeoptimizer.model.GetRecommendationSummariesResponse =
      zio.aws.computeoptimizer.model.GetRecommendationSummariesResponse(
        nextToken.map(value => value),
        recommendationSummaries.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def nextToken: Optional[NextToken]
    def recommendationSummaries: Optional[
      List[zio.aws.computeoptimizer.model.RecommendationSummary.ReadOnly]
    ]
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getRecommendationSummaries: ZIO[Any, AwsError, List[
      zio.aws.computeoptimizer.model.RecommendationSummary.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "recommendationSummaries",
      recommendationSummaries
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.computeoptimizer.model.GetRecommendationSummariesResponse
  ) extends zio.aws.computeoptimizer.model.GetRecommendationSummariesResponse.ReadOnly {
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.computeoptimizer.model.primitives.NextToken(value))
    override val recommendationSummaries: Optional[
      List[zio.aws.computeoptimizer.model.RecommendationSummary.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.recommendationSummaries())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.computeoptimizer.model.RecommendationSummary.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.computeoptimizer.model.GetRecommendationSummariesResponse
  ): zio.aws.computeoptimizer.model.GetRecommendationSummariesResponse.ReadOnly =
    new Wrapper(impl)
}
